	{0x0000, 0x001F, "Common", "Control"},
	{0x0020, 0x0020, "Common", "Separator"},
	{0x0021, 0x0023, "Common", "Punctuation"},
	{0x0024, 0x0024, "Common", "Currency Symbol"},
	{0x0025, 0x002A, "Common", "Punctuation"},
	{0x002B, 0x002B, "Common", "Symbol"},
	{0x002C, 0x002F, "Common", "Punctuation"},
	{0x0030, 0x0039, "Common", "Number"},
	{0x003A, 0x003B, "Common", "Punctuation"},
	{0x003C, 0x003E, "Common", "Symbol"},
	{0x003F, 0x0040, "Common", "Punctuation"},
	{0x0041, 0x005A, "Latin", "Letter"},
	{0x005B, 0x005D, "Common", "Punctuation"},
	{0x005E, 0x005E, "Common", "Symbol"},
	{0x005F, 0x005F, "Common", "Punctuation"},
	{0x0060, 0x0060, "Common", "Symbol"},
	{0x0061, 0x007A, "Latin", "Letter"},
	{0x007B, 0x007B, "Common", "Punctuation"},
	{0x007C, 0x007C, "Common", "Symbol"},
	{0x007D, 0x007D, "Common", "Punctuation"},
	{0x007E, 0x007E, "Common", "Symbol"},
	{0x007F, 0x009F, "Common", "Control"},
	{0x00A0, 0x00A0, "Common", "Separator"},
	{0x00A1, 0x00A1, "Common", "Punctuation"},
	{0x00A2, 0x00A5, "Common", "Currency Symbol"},
	{0x00A6, 0x00A9, "Common", "Symbol"},
	{0x00AA, 0x00AA, "Latin", "Letter"},
	{0x00AB, 0x00AB, "Common", "Punctuation"},
	{0x00AC, 0x00AC, "Common", "Symbol"},
	{0x00AD, 0x00AD, "Common", "Format"},
	{0x00AE, 0x00B1, "Common", "Symbol"},
	{0x00B2, 0x00B3, "Common", "Number"},
	{0x00B4, 0x00B4, "Common", "Symbol"},
	{0x00B5, 0x00B5, "Common", "Letter"},
	{0x00B6, 0x00B6, "Common", "Symbol"},
	{0x00B7, 0x00B7, "Common", "Punctuation"},
	{0x00B8, 0x00B8, "Common", "Symbol"},
	{0x00B9, 0x00B9, "Common", "Number"},
	{0x00BA, 0x00BA, "Latin", "Letter"},
	{0x00BB, 0x00BB, "Common", "Punctuation"},
	{0x00BC, 0x00BE, "Common", "Number"},
	{0x00BF, 0x00BF, "Common", "Punctuation"},
	{0x00C0, 0x00D6, "Latin", "Letter"},
	{0x00D7, 0x00D7, "Common", "Symbol"},
	{0x00D8, 0x00F6, "Latin", "Letter"},
	{0x00F7, 0x00F7, "Common", "Symbol"},
	{0x00F8, 0x02B8, "Latin", "Letter"},
	{0x02B9, 0x02C1, "Common", "Letter"},
	{0x02C2, 0x02C5, "Common", "Symbol"},
	{0x02C6, 0x02D1, "Common", "Letter"},
	{0x02D2, 0x02DF, "Common", "Symbol"},
	{0x02E0, 0x02E4, "Latin", "Letter"},
	{0x02E5, 0x02ED, "Common", "Symbol"},
	{0x02EE, 0x02EE, "Common", "Letter"},
	{0x02EF, 0x02FF, "Common", "Symbol"},
	{0x0300, 0x036F, "Inherited", "Mark"},
	{0x0374, 0x0375, "Greek", "Symbol"},
	{0x037A, 0x037D, "Greek", "Letter"},
	{0x037E, 0x037E, "Common", "Punctuation"},
	{0x0384, 0x0385, "Greek", "Symbol"},
	{0x0386, 0x0386, "Greek", "Letter"},
	{0x0387, 0x0387, "Common", "Punctuation"},
	{0x0388, 0x038A, "Greek", "Letter"},
	{0x038C, 0x038C, "Greek", "Letter"},
	{0x038E, 0x03A1, "Greek", "Letter"},
	{0x03A3, 0x03CE, "Greek", "Letter"},
	{0x03D0, 0x03E1, "Greek", "Letter"},
	{0x03E2, 0x03EF, "Coptic", "Letter"},
	{0x03F0, 0x03F5, "Greek", "Letter"},
	{0x03F6, 0x03F6, "Greek", "Symbol"},
	{0x03F7, 0x03FF, "Greek", "Letter"},
	{0x0400, 0x0481, "Cyrillic", "Letter"},
	{0x0482, 0x0482, "Cyrillic", "Symbol"},
	{0x0483, 0x0486, "Cyrillic", "Mark"},
	{0x0488, 0x0489, "Cyrillic", "Mark"},
	{0x048A, 0x0513, "Cyrillic", "Letter"},
	{0x0531, 0x0556, "Armenian", "Letter"},
	{0x0559, 0x0559, "Armenian", "Letter"},
	{0x055A, 0x055F, "Armenian", "Punctuation"},
	{0x0561, 0x0587, "Armenian", "Letter"},
	{0x0589, 0x0589, "Common", "Punctuation"},
	{0x058A, 0x058A, "Armenian", "Punctuation"},
	{0x0591, 0x05BD, "Hebrew", "Mark"},
	{0x05BE, 0x05BE, "Hebrew", "Punctuation"},
	{0x05BF, 0x05BF, "Hebrew", "Mark"},
	{0x05C0, 0x05C0, "Hebrew", "Punctuation"},
	{0x05C1, 0x05C2, "Hebrew", "Mark"},
	{0x05C3, 0x05C3, "Hebrew", "Punctuation"},
	{0x05C4, 0x05C5, "Hebrew", "Mark"},
	{0x05C6, 0x05C6, "Hebrew", "Punctuation"},
	{0x05C7, 0x05C7, "Hebrew", "Mark"},
	{0x05D0, 0x05EA, "Hebrew", "Letter"},
	{0x05F0, 0x05F2, "Hebrew", "Letter"},
	{0x05F3, 0x05F4, "Hebrew", "Punctuation"},
	{0x0600, 0x0603, "Common", "Format"},
	{0x060B, 0x060B, "Arabic", "Currency Symbol"},
	{0x060C, 0x060C, "Common", "Punctuation"},
	{0x060D, 0x060D, "Arabic", "Punctuation"},
	{0x060E, 0x060F, "Arabic", "Symbol"},
	{0x0610, 0x0615, "Arabic", "Mark"},
	{0x061B, 0x061B, "Common", "Punctuation"},
	{0x061E, 0x061E, "Arabic", "Punctuation"},
	{0x061F, 0x061F, "Common", "Punctuation"},
	{0x0621, 0x063A, "Arabic", "Letter"},
	{0x0640, 0x0640, "Common", "Letter"},
	{0x0641, 0x064A, "Arabic", "Letter"},
	{0x064B, 0x0655, "Inherited", "Mark"},
	{0x0656, 0x065E, "Arabic", "Mark"},
	{0x0660, 0x0669, "Common", "Number"},
	{0x066A, 0x066D, "Arabic", "Punctuation"},
	{0x066E, 0x066F, "Arabic", "Letter"},
	{0x0670, 0x0670, "Inherited", "Mark"},
	{0x0671, 0x06D3, "Arabic", "Letter"},
	{0x06D4, 0x06D4, "Arabic", "Punctuation"},
	{0x06D5, 0x06D5, "Arabic", "Letter"},
	{0x06D6, 0x06DC, "Arabic", "Mark"},
	{0x06DD, 0x06DD, "Common", "Format"},
	{0x06DE, 0x06E4, "Arabic", "Mark"},
	{0x06E5, 0x06E6, "Arabic", "Letter"},
	{0x06E7, 0x06E8, "Arabic", "Mark"},
	{0x06E9, 0x06E9, "Arabic", "Symbol"},
	{0x06EA, 0x06ED, "Arabic", "Mark"},
	{0x06EE, 0x06EF, "Arabic", "Letter"},
	{0x06F0, 0x06F9, "Arabic", "Number"},
	{0x06FA, 0x06FC, "Arabic", "Letter"},
	{0x06FD, 0x06FE, "Arabic", "Symbol"},
	{0x06FF, 0x06FF, "Arabic", "Letter"},
	{0x0700, 0x070D, "Syriac", "Punctuation"},
	{0x070F, 0x070F, "Syriac", "Format"},
	{0x0710, 0x0710, "Syriac", "Letter"},
	{0x0711, 0x0711, "Syriac", "Mark"},
	{0x0712, 0x072F, "Syriac", "Letter"},
	{0x0730, 0x074A, "Syriac", "Mark"},
	{0x074D, 0x074F, "Syriac", "Letter"},
	{0x0750, 0x076D, "Arabic", "Letter"},
	{0x0780, 0x07A5, "Thaana", "Letter"},
	{0x07A6, 0x07B0, "Thaana", "Mark"},
	{0x07B1, 0x07B1, "Thaana", "Letter"},
	{0x07C0, 0x07C9, "Nko", "Number"},
	{0x07CA, 0x07EA, "Nko", "Letter"},
	{0x07EB, 0x07F3, "Nko", "Mark"},
	{0x07F4, 0x07F5, "Nko", "Letter"},
	{0x07F6, 0x07F6, "Nko", "Symbol"},
	{0x07F7, 0x07F9, "Nko", "Punctuation"},
	{0x07FA, 0x07FA, "Nko", "Letter"},
	{0x0901, 0x0903, "Devanagari", "Mark"},
	{0x0904, 0x0939, "Devanagari", "Letter"},
	{0x093C, 0x093C, "Devanagari", "Mark"},
	{0x093D, 0x093D, "Devanagari", "Letter"},
	{0x093E, 0x094D, "Devanagari", "Mark"},
	{0x0950, 0x0950, "Devanagari", "Letter"},
	{0x0951, 0x0954, "Devanagari", "Mark"},
	{0x0958, 0x0961, "Devanagari", "Letter"},
	{0x0962, 0x0963, "Devanagari", "Mark"},
	{0x0964, 0x0965, "Common", "Punctuation"},
	{0x0966, 0x096F, "Devanagari", "Number"},
	{0x0970, 0x0970, "Common", "Punctuation"},
	{0x097B, 0x097F, "Devanagari", "Letter"},
	{0x0981, 0x0983, "Bengali", "Mark"},
	{0x0985, 0x098C, "Bengali", "Letter"},
	{0x098F, 0x0990, "Bengali", "Letter"},
	{0x0993, 0x09A8, "Bengali", "Letter"},
	{0x09AA, 0x09B0, "Bengali", "Letter"},
	{0x09B2, 0x09B2, "Bengali", "Letter"},
	{0x09B6, 0x09B9, "Bengali", "Letter"},
	{0x09BC, 0x09BC, "Bengali", "Mark"},
	{0x09BD, 0x09BD, "Bengali", "Letter"},
	{0x09BE, 0x09C4, "Bengali", "Mark"},
	{0x09C7, 0x09C8, "Bengali", "Mark"},
	{0x09CB, 0x09CD, "Bengali", "Mark"},
	{0x09CE, 0x09CE, "Bengali", "Letter"},
	{0x09D7, 0x09D7, "Bengali", "Mark"},
	{0x09DC, 0x09DD, "Bengali", "Letter"},
	{0x09DF, 0x09E1, "Bengali", "Letter"},
	{0x09E2, 0x09E3, "Bengali", "Mark"},
	{0x09E6, 0x09EF, "Bengali", "Number"},
	{0x09F0, 0x09F1, "Bengali", "Letter"},
	{0x09F2, 0x09F3, "Bengali", "Currency Symbol"},
	{0x09F4, 0x09F9, "Bengali", "Number"},
	{0x09FA, 0x09FA, "Bengali", "Symbol"},
	{0x0A01, 0x0A03, "Gurmukhi", "Mark"},
	{0x0A05, 0x0A0A, "Gurmukhi", "Letter"},
	{0x0A0F, 0x0A10, "Gurmukhi", "Letter"},
	{0x0A13, 0x0A28, "Gurmukhi", "Letter"},
	{0x0A2A, 0x0A30, "Gurmukhi", "Letter"},
	{0x0A32, 0x0A33, "Gurmukhi", "Letter"},
	{0x0A35, 0x0A36, "Gurmukhi", "Letter"},
	{0x0A38, 0x0A39, "Gurmukhi", "Letter"},
	{0x0A3C, 0x0A3C, "Gurmukhi", "Mark"},
	{0x0A3E, 0x0A42, "Gurmukhi", "Mark"},
	{0x0A47, 0x0A48, "Gurmukhi", "Mark"},
	{0x0A4B, 0x0A4D, "Gurmukhi", "Mark"},
	{0x0A59, 0x0A5C, "Gurmukhi", "Letter"},
	{0x0A5E, 0x0A5E, "Gurmukhi", "Letter"},
	{0x0A66, 0x0A6F, "Gurmukhi", "Number"},
	{0x0A70, 0x0A71, "Gurmukhi", "Mark"},
	{0x0A72, 0x0A74, "Gurmukhi", "Letter"},
	{0x0A81, 0x0A83, "Gujarati", "Mark"},
	{0x0A85, 0x0A8D, "Gujarati", "Letter"},
	{0x0A8F, 0x0A91, "Gujarati", "Letter"},
	{0x0A93, 0x0AA8, "Gujarati", "Letter"},
	{0x0AAA, 0x0AB0, "Gujarati", "Letter"},
	{0x0AB2, 0x0AB3, "Gujarati", "Letter"},
	{0x0AB5, 0x0AB9, "Gujarati", "Letter"},
	{0x0ABC, 0x0ABC, "Gujarati", "Mark"},
	{0x0ABD, 0x0ABD, "Gujarati", "Letter"},
	{0x0ABE, 0x0AC5, "Gujarati", "Mark"},
	{0x0AC7, 0x0AC9, "Gujarati", "Mark"},
	{0x0ACB, 0x0ACD, "Gujarati", "Mark"},
	{0x0AD0, 0x0AD0, "Gujarati", "Letter"},
	{0x0AE0, 0x0AE1, "Gujarati", "Letter"},
	{0x0AE2, 0x0AE3, "Gujarati", "Mark"},
	{0x0AE6, 0x0AEF, "Gujarati", "Number"},
	{0x0AF1, 0x0AF1, "Gujarati", "Currency Symbol"},
	{0x0B01, 0x0B03, "Oriya", "Mark"},
	{0x0B05, 0x0B0C, "Oriya", "Letter"},
	{0x0B0F, 0x0B10, "Oriya", "Letter"},
	{0x0B13, 0x0B28, "Oriya", "Letter"},
	{0x0B2A, 0x0B30, "Oriya", "Letter"},
	{0x0B32, 0x0B33, "Oriya", "Letter"},
	{0x0B35, 0x0B39, "Oriya", "Letter"},
	{0x0B3C, 0x0B3C, "Oriya", "Mark"},
	{0x0B3D, 0x0B3D, "Oriya", "Letter"},
	{0x0B3E, 0x0B43, "Oriya", "Mark"},
	{0x0B47, 0x0B48, "Oriya", "Mark"},
	{0x0B4B, 0x0B4D, "Oriya", "Mark"},
	{0x0B56, 0x0B57, "Oriya", "Mark"},
	{0x0B5C, 0x0B5D, "Oriya", "Letter"},
	{0x0B5F, 0x0B61, "Oriya", "Letter"},
	{0x0B66, 0x0B6F, "Oriya", "Number"},
	{0x0B70, 0x0B70, "Oriya", "Symbol"},
	{0x0B71, 0x0B71, "Oriya", "Letter"},
	{0x0B82, 0x0B82, "Tamil", "Mark"},
	{0x0B83, 0x0B83, "Tamil", "Letter"},
	{0x0B85, 0x0B8A, "Tamil", "Letter"},
	{0x0B8E, 0x0B90, "Tamil", "Letter"},
	{0x0B92, 0x0B95, "Tamil", "Letter"},
	{0x0B99, 0x0B9A, "Tamil", "Letter"},
	{0x0B9C, 0x0B9C, "Tamil", "Letter"},
	{0x0B9E, 0x0B9F, "Tamil", "Letter"},
	{0x0BA3, 0x0BA4, "Tamil", "Letter"},
	{0x0BA8, 0x0BAA, "Tamil", "Letter"},
	{0x0BAE, 0x0BB9, "Tamil", "Letter"},
	{0x0BBE, 0x0BC2, "Tamil", "Mark"},
	{0x0BC6, 0x0BC8, "Tamil", "Mark"},
	{0x0BCA, 0x0BCD, "Tamil", "Mark"},
	{0x0BD7, 0x0BD7, "Tamil", "Mark"},
	{0x0BE6, 0x0BF2, "Tamil", "Number"},
	{0x0BF3, 0x0BF8, "Tamil", "Symbol"},
	{0x0BF9, 0x0BF9, "Tamil", "Currency Symbol"},
	{0x0BFA, 0x0BFA, "Tamil", "Symbol"},
	{0x0C01, 0x0C03, "Telugu", "Mark"},
	{0x0C05, 0x0C0C, "Telugu", "Letter"},
	{0x0C0E, 0x0C10, "Telugu", "Letter"},
	{0x0C12, 0x0C28, "Telugu", "Letter"},
	{0x0C2A, 0x0C33, "Telugu", "Letter"},
	{0x0C35, 0x0C39, "Telugu", "Letter"},
	{0x0C3E, 0x0C44, "Telugu", "Mark"},
	{0x0C46, 0x0C48, "Telugu", "Mark"},
	{0x0C4A, 0x0C4D, "Telugu", "Mark"},
	{0x0C55, 0x0C56, "Telugu", "Mark"},
	{0x0C60, 0x0C61, "Telugu", "Letter"},
	{0x0C66, 0x0C6F, "Telugu", "Number"},
	{0x0C82, 0x0C83, "Kannada", "Mark"},
	{0x0C85, 0x0C8C, "Kannada", "Letter"},
	{0x0C8E, 0x0C90, "Kannada", "Letter"},
	{0x0C92, 0x0CA8, "Kannada", "Letter"},
	{0x0CAA, 0x0CB3, "Kannada", "Letter"},
	{0x0CB5, 0x0CB9, "Kannada", "Letter"},
	{0x0CBC, 0x0CBC, "Kannada", "Mark"},
	{0x0CBD, 0x0CBD, "Kannada", "Letter"},
	{0x0CBE, 0x0CC4, "Kannada", "Mark"},
	{0x0CC6, 0x0CC8, "Kannada", "Mark"},
	{0x0CCA, 0x0CCD, "Kannada", "Mark"},
	{0x0CD5, 0x0CD6, "Kannada", "Mark"},
	{0x0CDE, 0x0CDE, "Kannada", "Letter"},
	{0x0CE0, 0x0CE1, "Kannada", "Letter"},
	{0x0CE2, 0x0CE3, "Kannada", "Mark"},
	{0x0CE6, 0x0CEF, "Kannada", "Number"},
	{0x0CF1, 0x0CF2, "Kannada", "Symbol"},
	{0x0D02, 0x0D03, "Malayalam", "Mark"},
	{0x0D05, 0x0D0C, "Malayalam", "Letter"},
	{0x0D0E, 0x0D10, "Malayalam", "Letter"},
	{0x0D12, 0x0D28, "Malayalam", "Letter"},
	{0x0D2A, 0x0D39, "Malayalam", "Letter"},
	{0x0D3E, 0x0D43, "Malayalam", "Mark"},
	{0x0D46, 0x0D48, "Malayalam", "Mark"},
	{0x0D4A, 0x0D4D, "Malayalam", "Mark"},
	{0x0D57, 0x0D57, "Malayalam", "Mark"},
	{0x0D60, 0x0D61, "Malayalam", "Letter"},
	{0x0D66, 0x0D6F, "Malayalam", "Number"},
	{0x0D82, 0x0D83, "Sinhala", "Mark"},
	{0x0D85, 0x0D96, "Sinhala", "Letter"},
	{0x0D9A, 0x0DB1, "Sinhala", "Letter"},
	{0x0DB3, 0x0DBB, "Sinhala", "Letter"},
	{0x0DBD, 0x0DBD, "Sinhala", "Letter"},
	{0x0DC0, 0x0DC6, "Sinhala", "Letter"},
	{0x0DCA, 0x0DCA, "Sinhala", "Mark"},
	{0x0DCF, 0x0DD4, "Sinhala", "Mark"},
	{0x0DD6, 0x0DD6, "Sinhala", "Mark"},
	{0x0DD8, 0x0DDF, "Sinhala", "Mark"},
	{0x0DF2, 0x0DF3, "Sinhala", "Mark"},
	{0x0DF4, 0x0DF4, "Sinhala", "Punctuation"},
	{0x0E01, 0x0E30, "Thai", "Letter"},
	{0x0E31, 0x0E31, "Thai", "Mark"},
	{0x0E32, 0x0E33, "Thai", "Letter"},
	{0x0E34, 0x0E3A, "Thai", "Mark"},
	{0x0E3F, 0x0E3F, "Common", "Currency Symbol"},
	{0x0E40, 0x0E46, "Thai", "Letter"},
	{0x0E47, 0x0E4E, "Thai", "Mark"},
	{0x0E4F, 0x0E4F, "Thai", "Punctuation"},
	{0x0E50, 0x0E59, "Thai", "Number"},
	{0x0E5A, 0x0E5B, "Thai", "Punctuation"},
	{0x0E81, 0x0E82, "Lao", "Letter"},
	{0x0E84, 0x0E84, "Lao", "Letter"},
	{0x0E87, 0x0E88, "Lao", "Letter"},
	{0x0E8A, 0x0E8A, "Lao", "Letter"},
	{0x0E8D, 0x0E8D, "Lao", "Letter"},
	{0x0E94, 0x0E97, "Lao", "Letter"},
	{0x0E99, 0x0E9F, "Lao", "Letter"},
	{0x0EA1, 0x0EA3, "Lao", "Letter"},
	{0x0EA5, 0x0EA5, "Lao", "Letter"},
	{0x0EA7, 0x0EA7, "Lao", "Letter"},
	{0x0EAA, 0x0EAB, "Lao", "Letter"},
	{0x0EAD, 0x0EB0, "Lao", "Letter"},
	{0x0EB1, 0x0EB1, "Lao", "Mark"},
	{0x0EB2, 0x0EB3, "Lao", "Letter"},
	{0x0EB4, 0x0EB9, "Lao", "Mark"},
	{0x0EBB, 0x0EBC, "Lao", "Mark"},
	{0x0EBD, 0x0EBD, "Lao", "Letter"},
	{0x0EC0, 0x0EC4, "Lao", "Letter"},
	{0x0EC6, 0x0EC6, "Lao", "Letter"},
	{0x0EC8, 0x0ECD, "Lao", "Mark"},
	{0x0ED0, 0x0ED9, "Lao", "Number"},
	{0x0EDC, 0x0EDD, "Lao", "Letter"},
	{0x0F00, 0x0F00, "Tibetan", "Letter"},
	{0x0F01, 0x0F03, "Tibetan", "Symbol"},
	{0x0F04, 0x0F12, "Tibetan", "Punctuation"},
	{0x0F13, 0x0F17, "Tibetan", "Symbol"},
	{0x0F18, 0x0F19, "Tibetan", "Mark"},
	{0x0F1A, 0x0F1F, "Tibetan", "Symbol"},
	{0x0F20, 0x0F33, "Tibetan", "Number"},
	{0x0F34, 0x0F34, "Tibetan", "Symbol"},
	{0x0F35, 0x0F35, "Tibetan", "Mark"},
	{0x0F36, 0x0F36, "Tibetan", "Symbol"},
	{0x0F37, 0x0F37, "Tibetan", "Mark"},
	{0x0F38, 0x0F38, "Tibetan", "Symbol"},
	{0x0F39, 0x0F39, "Tibetan", "Mark"},
	{0x0F3A, 0x0F3D, "Tibetan", "Punctuation"},
	{0x0F3E, 0x0F3F, "Tibetan", "Mark"},
	{0x0F40, 0x0F47, "Tibetan", "Letter"},
	{0x0F49, 0x0F6A, "Tibetan", "Letter"},
	{0x0F71, 0x0F84, "Tibetan", "Mark"},
	{0x0F85, 0x0F85, "Tibetan", "Punctuation"},
	{0x0F86, 0x0F87, "Tibetan", "Mark"},
	{0x0F88, 0x0F8B, "Tibetan", "Letter"},
	{0x0F90, 0x0F97, "Tibetan", "Mark"},
	{0x0F99, 0x0FBC, "Tibetan", "Mark"},
	{0x0FBE, 0x0FC5, "Tibetan", "Symbol"},
	{0x0FC6, 0x0FC6, "Tibetan", "Mark"},
	{0x0FC7, 0x0FCC, "Tibetan", "Symbol"},
	{0x0FCF, 0x0FCF, "Tibetan", "Symbol"},
	{0x0FD0, 0x0FD1, "Tibetan", "Punctuation"},
	{0x1000, 0x1021, "Myanmar", "Letter"},
	{0x1023, 0x1027, "Myanmar", "Letter"},
	{0x1029, 0x102A, "Myanmar", "Letter"},
	{0x102C, 0x1032, "Myanmar", "Mark"},
	{0x1036, 0x1039, "Myanmar", "Mark"},
	{0x1040, 0x1049, "Myanmar", "Number"},
	{0x104A, 0x104F, "Myanmar", "Punctuation"},
	{0x1050, 0x1055, "Myanmar", "Letter"},
	{0x1056, 0x1059, "Myanmar", "Mark"},
	{0x10A0, 0x10C5, "Georgian", "Letter"},
	{0x10D0, 0x10FA, "Georgian", "Letter"},
	{0x10FB, 0x10FB, "Common", "Punctuation"},
	{0x10FC, 0x10FC, "Georgian", "Letter"},
	{0x1100, 0x1159, "Hangul", "Letter"},
	{0x115F, 0x11A2, "Hangul", "Letter"},
	{0x11A8, 0x11F9, "Hangul", "Letter"},
	{0x1200, 0x1248, "Ethiopic", "Letter"},
	{0x124A, 0x124D, "Ethiopic", "Letter"},
	{0x1250, 0x1256, "Ethiopic", "Letter"},
	{0x1258, 0x1258, "Ethiopic", "Letter"},
	{0x125A, 0x125D, "Ethiopic", "Letter"},
	{0x1260, 0x1288, "Ethiopic", "Letter"},
	{0x128A, 0x128D, "Ethiopic", "Letter"},
	{0x1290, 0x12B0, "Ethiopic", "Letter"},
	{0x12B2, 0x12B5, "Ethiopic", "Letter"},
	{0x12B8, 0x12BE, "Ethiopic", "Letter"},
	{0x12C0, 0x12C0, "Ethiopic", "Letter"},
	{0x12C2, 0x12C5, "Ethiopic", "Letter"},
	{0x12C8, 0x12D6, "Ethiopic", "Letter"},
	{0x12D8, 0x1310, "Ethiopic", "Letter"},
	{0x1312, 0x1315, "Ethiopic", "Letter"},
	{0x1318, 0x135A, "Ethiopic", "Letter"},
	{0x135F, 0x135F, "Ethiopic", "Mark"},
	{0x1360, 0x1360, "Ethiopic", "Symbol"},
	{0x1361, 0x1368, "Ethiopic", "Punctuation"},
	{0x1369, 0x137C, "Ethiopic", "Number"},
	{0x1380, 0x138F, "Ethiopic", "Letter"},
	{0x1390, 0x1399, "Ethiopic", "Symbol"},
	{0x13A0, 0x13F4, "Cherokee", "Letter"},
	{0x1401, 0x166C, "Canadian Aboriginal", "Letter"},
	{0x166D, 0x166E, "Canadian Aboriginal", "Punctuation"},
	{0x166F, 0x1676, "Canadian Aboriginal", "Letter"},
	{0x1680, 0x1680, "Ogham", "Separator"},
	{0x1681, 0x169A, "Ogham", "Letter"},
	{0x169B, 0x169C, "Ogham", "Punctuation"},
	{0x16A0, 0x16EA, "Runic", "Letter"},
	{0x16EB, 0x16ED, "Common", "Punctuation"},
	{0x16EE, 0x16F0, "Runic", "Number"},
	{0x1700, 0x170C, "Tagalog", "Letter"},
	{0x170E, 0x1711, "Tagalog", "Letter"},
	{0x1712, 0x1714, "Tagalog", "Mark"},
	{0x1720, 0x1731, "Hanunoo", "Letter"},
	{0x1732, 0x1734, "Hanunoo", "Mark"},
	{0x1735, 0x1736, "Common", "Punctuation"},
	{0x1740, 0x1751, "Buhid", "Letter"},
	{0x1752, 0x1753, "Buhid", "Mark"},
	{0x1760, 0x176C, "Tagbanwa", "Letter"},
	{0x176E, 0x1770, "Tagbanwa", "Letter"},
	{0x1772, 0x1773, "Tagbanwa", "Mark"},
	{0x1780, 0x17B3, "Khmer", "Letter"},
	{0x17B4, 0x17B5, "Khmer", "Format"},
	{0x17B6, 0x17D3, "Khmer", "Mark"},
	{0x17D4, 0x17D6, "Khmer", "Punctuation"},
	{0x17D7, 0x17D7, "Khmer", "Letter"},
	{0x17D8, 0x17DA, "Khmer", "Punctuation"},
	{0x17DB, 0x17DB, "Khmer", "Currency Symbol"},
	{0x17DC, 0x17DC, "Khmer", "Letter"},
	{0x17DD, 0x17DD, "Khmer", "Mark"},
	{0x17E0, 0x17E9, "Khmer", "Number"},
	{0x17F0, 0x17F9, "Khmer", "Number"},
	{0x1800, 0x1801, "Mongolian", "Punctuation"},
	{0x1802, 0x1803, "Common", "Punctuation"},
	{0x1804, 0x1804, "Mongolian", "Punctuation"},
	{0x1805, 0x1805, "Common", "Punctuation"},
	{0x1806, 0x180A, "Mongolian", "Punctuation"},
	{0x180B, 0x180D, "Mongolian", "Mark"},
	{0x180E, 0x180E, "Mongolian", "Separator"},
	{0x1810, 0x1819, "Mongolian", "Number"},
	{0x1820, 0x1877, "Mongolian", "Letter"},
	{0x1880, 0x18A8, "Mongolian", "Letter"},
	{0x18A9, 0x18A9, "Mongolian", "Mark"},
	{0x1900, 0x191C, "Limbu", "Letter"},
	{0x1920, 0x192B, "Limbu", "Mark"},
	{0x1930, 0x193B, "Limbu", "Mark"},
	{0x1940, 0x1940, "Limbu", "Symbol"},
	{0x1944, 0x1945, "Limbu", "Punctuation"},
	{0x1946, 0x194F, "Limbu", "Number"},
	{0x1950, 0x196D, "Tai Le", "Letter"},
	{0x1970, 0x1974, "Tai Le", "Letter"},
	{0x1980, 0x19A9, "New Tai Lue", "Letter"},
	{0x19B0, 0x19C0, "New Tai Lue", "Mark"},
	{0x19C1, 0x19C7, "New Tai Lue", "Letter"},
	{0x19C8, 0x19C9, "New Tai Lue", "Mark"},
	{0x19D0, 0x19D9, "New Tai Lue", "Number"},
	{0x19DE, 0x19DF, "New Tai Lue", "Punctuation"},
	{0x19E0, 0x19FF, "Khmer", "Symbol"},
	{0x1A00, 0x1A16, "Buginese", "Letter"},
	{0x1A17, 0x1A1B, "Buginese", "Mark"},
	{0x1A1E, 0x1A1F, "Buginese", "Punctuation"},
	{0x1B00, 0x1B04, "Balinese", "Mark"},
	{0x1B05, 0x1B33, "Balinese", "Letter"},
	{0x1B34, 0x1B44, "Balinese", "Mark"},
	{0x1B45, 0x1B4B, "Balinese", "Letter"},
	{0x1B50, 0x1B59, "Balinese", "Number"},
	{0x1B5A, 0x1B60, "Balinese", "Punctuation"},
	{0x1B61, 0x1B6A, "Balinese", "Symbol"},
	{0x1B6B, 0x1B73, "Balinese", "Mark"},
	{0x1B74, 0x1B7C, "Balinese", "Symbol"},
	{0x1D00, 0x1D25, "Latin", "Letter"},
	{0x1D26, 0x1D2A, "Greek", "Letter"},
	{0x1D2B, 0x1D2B, "Cyrillic", "Letter"},
	{0x1D2C, 0x1D5C, "Latin", "Letter"},
	{0x1D5D, 0x1D61, "Greek", "Letter"},
	{0x1D62, 0x1D65, "Latin", "Letter"},
	{0x1D66, 0x1D6A, "Greek", "Letter"},
	{0x1D6B, 0x1D77, "Latin", "Letter"},
	{0x1D78, 0x1D78, "Cyrillic", "Letter"},
	{0x1D79, 0x1DBE, "Latin", "Letter"},
	{0x1DBF, 0x1DBF, "Greek", "Letter"},
	{0x1DC0, 0x1DCA, "Inherited", "Mark"},
	{0x1DFE, 0x1DFF, "Inherited", "Mark"},
	{0x1E00, 0x1E9B, "Latin", "Letter"},
	{0x1EA0, 0x1EF9, "Latin", "Letter"},
	{0x1F00, 0x1F15, "Greek", "Letter"},
	{0x1F18, 0x1F1D, "Greek", "Letter"},
	{0x1F20, 0x1F45, "Greek", "Letter"},
	{0x1F48, 0x1F4D, "Greek", "Letter"},
	{0x1F50, 0x1F57, "Greek", "Letter"},
	{0x1F59, 0x1F59, "Greek", "Letter"},
	{0x1F5B, 0x1F5B, "Greek", "Letter"},
	{0x1F5D, 0x1F5D, "Greek", "Letter"},
	{0x1F5F, 0x1F7D, "Greek", "Letter"},
	{0x1F80, 0x1FB4, "Greek", "Letter"},
	{0x1FB6, 0x1FBC, "Greek", "Letter"},
	{0x1FBD, 0x1FBD, "Greek", "Symbol"},
	{0x1FBE, 0x1FBE, "Greek", "Letter"},
	{0x1FBF, 0x1FC1, "Greek", "Symbol"},
	{0x1FC2, 0x1FC4, "Greek", "Letter"},
	{0x1FC6, 0x1FCC, "Greek", "Letter"},
	{0x1FCD, 0x1FCF, "Greek", "Symbol"},
	{0x1FD0, 0x1FD3, "Greek", "Letter"},
	{0x1FD6, 0x1FDB, "Greek", "Letter"},
	{0x1FDD, 0x1FDF, "Greek", "Symbol"},
	{0x1FE0, 0x1FEC, "Greek", "Letter"},
	{0x1FED, 0x1FEF, "Greek", "Symbol"},
	{0x1FF2, 0x1FF4, "Greek", "Letter"},
	{0x1FF6, 0x1FFC, "Greek", "Letter"},
	{0x1FFD, 0x1FFE, "Greek", "Symbol"},
	{0x2000, 0x200A, "Common", "Separator"},
	{0x200B, 0x200B, "Common", "Format"},
	{0x200C, 0x200D, "Inherited", "Format"},
	{0x200E, 0x200F, "Common", "Format"},
	{0x2010, 0x2027, "Common", "Punctuation"},
	{0x2028, 0x2029, "Common", "Separator"},
	{0x202A, 0x202E, "Common", "Format"},
	{0x202F, 0x202F, "Common", "Separator"},
	{0x2030, 0x2043, "Common", "Punctuation"},
	{0x2044, 0x2044, "Common", "Symbol"},
	{0x2045, 0x2051, "Common", "Punctuation"},
	{0x2052, 0x2052, "Common", "Symbol"},
	{0x2053, 0x205E, "Common", "Punctuation"},
	{0x205F, 0x205F, "Common", "Separator"},
	{0x2060, 0x2063, "Common", "Format"},
	{0x206A, 0x206F, "Common", "Format"},
	{0x2070, 0x2070, "Common", "Number"},
	{0x2071, 0x2071, "Latin", "Letter"},
	{0x2074, 0x2079, "Common", "Number"},
	{0x207A, 0x207C, "Common", "Symbol"},
	{0x207D, 0x207E, "Common", "Punctuation"},
	{0x207F, 0x207F, "Latin", "Letter"},
	{0x2080, 0x2089, "Common", "Number"},
	{0x208A, 0x208C, "Common", "Symbol"},
	{0x208D, 0x208E, "Common", "Punctuation"},
	{0x2090, 0x2094, "Latin", "Letter"},
	{0x20A0, 0x20B5, "Common", "Currency Symbol"},
	{0x20D0, 0x20EF, "Inherited", "Mark"},
	{0x2100, 0x2101, "Common", "Symbol"},
	{0x2102, 0x2102, "Common", "Letter"},
	{0x2103, 0x2106, "Common", "Symbol"},
	{0x2107, 0x2107, "Common", "Letter"},
	{0x2108, 0x2109, "Common", "Symbol"},
	{0x210A, 0x2113, "Common", "Letter"},
	{0x2114, 0x2114, "Common", "Symbol"},
	{0x2115, 0x2115, "Common", "Letter"},
	{0x2116, 0x2118, "Common", "Symbol"},
	{0x2119, 0x211D, "Common", "Letter"},
	{0x211E, 0x2123, "Common", "Symbol"},
	{0x2124, 0x2124, "Common", "Letter"},
	{0x2125, 0x2125, "Common", "Symbol"},
	{0x2126, 0x2126, "Greek", "Letter"},
	{0x2127, 0x2127, "Common", "Symbol"},
	{0x2128, 0x2128, "Common", "Letter"},
	{0x2129, 0x2129, "Common", "Symbol"},
	{0x212A, 0x212B, "Latin", "Letter"},
	{0x212C, 0x212D, "Common", "Letter"},
	{0x212E, 0x212E, "Common", "Symbol"},
	{0x212F, 0x2131, "Common", "Letter"},
	{0x2132, 0x2132, "Latin", "Letter"},
	{0x2133, 0x2139, "Common", "Letter"},
	{0x213A, 0x213B, "Common", "Symbol"},
	{0x213C, 0x213F, "Common", "Letter"},
	{0x2140, 0x2144, "Common", "Symbol"},
	{0x2145, 0x2149, "Common", "Letter"},
	{0x214A, 0x214D, "Common", "Symbol"},
	{0x214E, 0x214E, "Latin", "Letter"},
	{0x2153, 0x2182, "Common", "Number"},
	{0x2183, 0x2183, "Common", "Letter"},
	{0x2184, 0x2184, "Latin", "Letter"},
	{0x2190, 0x2328, "Common", "Symbol"},
	{0x2329, 0x232A, "Common", "Punctuation"},
	{0x232B, 0x23E7, "Common", "Symbol"},
	{0x2400, 0x2426, "Common", "Symbol"},
	{0x2440, 0x244A, "Common", "Symbol"},
	{0x2460, 0x249B, "Common", "Number"},
	{0x249C, 0x24E9, "Common", "Symbol"},
	{0x24EA, 0x24FF, "Common", "Number"},
	{0x2500, 0x269C, "Common", "Symbol"},
	{0x26A0, 0x26B2, "Common", "Symbol"},
	{0x2701, 0x2704, "Common", "Symbol"},
	{0x2706, 0x2709, "Common", "Symbol"},
	{0x270C, 0x2727, "Common", "Symbol"},
	{0x2729, 0x274B, "Common", "Symbol"},
	{0x274D, 0x274D, "Common", "Symbol"},
	{0x274F, 0x2752, "Common", "Symbol"},
	{0x2756, 0x2756, "Common", "Symbol"},
	{0x2758, 0x275E, "Common", "Symbol"},
	{0x2761, 0x2767, "Common", "Symbol"},
	{0x2768, 0x2775, "Common", "Punctuation"},
	{0x2776, 0x2793, "Common", "Number"},
	{0x2794, 0x2794, "Common", "Symbol"},
	{0x2798, 0x27AF, "Common", "Symbol"},
	{0x27B1, 0x27BE, "Common", "Symbol"},
	{0x27C0, 0x27C4, "Common", "Symbol"},
	{0x27C5, 0x27C6, "Common", "Punctuation"},
	{0x27C7, 0x27CA, "Common", "Symbol"},
	{0x27D0, 0x27E5, "Common", "Symbol"},
	{0x27E6, 0x27EB, "Common", "Punctuation"},
	{0x27F0, 0x27FF, "Common", "Symbol"},
	{0x2800, 0x28FF, "Braille", "Symbol"},
	{0x2900, 0x2982, "Common", "Symbol"},
	{0x2983, 0x2998, "Common", "Punctuation"},
	{0x2999, 0x29D7, "Common", "Symbol"},
	{0x29D8, 0x29DB, "Common", "Punctuation"},
	{0x29DC, 0x29FB, "Common", "Symbol"},
	{0x29FC, 0x29FD, "Common", "Punctuation"},
	{0x29FE, 0x2B1A, "Common", "Symbol"},
	{0x2B20, 0x2B23, "Common", "Symbol"},
	{0x2C00, 0x2C2E, "Glagolitic", "Letter"},
	{0x2C30, 0x2C5E, "Glagolitic", "Letter"},
	{0x2C60, 0x2C6C, "Latin", "Letter"},
	{0x2C74, 0x2C77, "Latin", "Letter"},
	{0x2C80, 0x2CE4, "Coptic", "Letter"},
	{0x2CE5, 0x2CEA, "Coptic", "Symbol"},
	{0x2CF9, 0x2CFC, "Coptic", "Punctuation"},
	{0x2CFD, 0x2CFD, "Coptic", "Number"},
	{0x2CFE, 0x2CFF, "Coptic", "Punctuation"},
	{0x2D00, 0x2D25, "Georgian", "Letter"},
	{0x2D30, 0x2D65, "Tifinagh", "Letter"},
	{0x2D6F, 0x2D6F, "Tifinagh", "Letter"},
	{0x2D80, 0x2D96, "Ethiopic", "Letter"},
	{0x2DA0, 0x2DA6, "Ethiopic", "Letter"},
	{0x2DA8, 0x2DAE, "Ethiopic", "Letter"},
	{0x2DB0, 0x2DB6, "Ethiopic", "Letter"},
	{0x2DB8, 0x2DBE, "Ethiopic", "Letter"},
	{0x2DC0, 0x2DC6, "Ethiopic", "Letter"},
	{0x2DC8, 0x2DCE, "Ethiopic", "Letter"},
	{0x2DD0, 0x2DD6, "Ethiopic", "Letter"},
	{0x2DD8, 0x2DDE, "Ethiopic", "Letter"},
	{0x2E00, 0x2E17, "Common", "Punctuation"},
	{0x2E1C, 0x2E1D, "Common", "Punctuation"},
	{0x2E80, 0x2E99, "Han", "Symbol"},
	{0x2E9B, 0x2EF3, "Han", "Symbol"},
	{0x2F00, 0x2FD5, "Han", "Symbol"},
	{0x2FF0, 0x2FFB, "Common", "Symbol"},
	{0x3000, 0x3000, "Common", "Separator"},
	{0x3001, 0x3003, "Common", "Punctuation"},
	{0x3004, 0x3004, "Common", "Symbol"},
	{0x3005, 0x3005, "Han", "Letter"},
	{0x3006, 0x3006, "Common", "Letter"},
	{0x3007, 0x3007, "Han", "Number"},
	{0x3008, 0x3011, "Common", "Punctuation"},
	{0x3012, 0x3013, "Common", "Symbol"},
	{0x3014, 0x301F, "Common", "Punctuation"},
	{0x3020, 0x3020, "Common", "Symbol"},
	{0x3021, 0x3029, "Han", "Number"},
	{0x302A, 0x302F, "Inherited", "Mark"},
	{0x3030, 0x3030, "Common", "Punctuation"},
	{0x3031, 0x3035, "Common", "Letter"},
	{0x3036, 0x3037, "Common", "Symbol"},
	{0x3038, 0x303A, "Han", "Number"},
	{0x303B, 0x303B, "Han", "Letter"},
	{0x303C, 0x303C, "Common", "Letter"},
	{0x303D, 0x303D, "Common", "Punctuation"},
	{0x303E, 0x303F, "Common", "Symbol"},
	{0x3041, 0x3096, "Hiragana", "Letter"},
	{0x3099, 0x309A, "Inherited", "Mark"},
	{0x309B, 0x309C, "Common", "Symbol"},
	{0x309D, 0x309F, "Hiragana", "Letter"},
	{0x30A0, 0x30A0, "Common", "Punctuation"},
	{0x30A1, 0x30FA, "Katakana", "Letter"},
	{0x30FB, 0x30FB, "Common", "Punctuation"},
	{0x30FC, 0x30FC, "Common", "Letter"},
	{0x30FD, 0x30FF, "Katakana", "Letter"},
	{0x3105, 0x312C, "Bopomofo", "Letter"},
	{0x3131, 0x318E, "Hangul", "Letter"},
	{0x3190, 0x3191, "Common", "Symbol"},
	{0x3192, 0x3195, "Common", "Number"},
	{0x3196, 0x319F, "Common", "Symbol"},
	{0x31A0, 0x31B7, "Bopomofo", "Letter"},
	{0x31C0, 0x31CF, "Common", "Symbol"},
	{0x31F0, 0x31FF, "Katakana", "Letter"},
	{0x3200, 0x321E, "Hangul", "Symbol"},
	{0x3220, 0x3229, "Common", "Number"},
	{0x322A, 0x3243, "Common", "Symbol"},
	{0x3250, 0x3250, "Common", "Symbol"},
	{0x3251, 0x325F, "Common", "Number"},
	{0x3260, 0x327D, "Hangul", "Symbol"},
	{0x327E, 0x327F, "Common", "Symbol"},
	{0x3280, 0x3289, "Common", "Number"},
	{0x328A, 0x32B0, "Common", "Symbol"},
	{0x32B1, 0x32BF, "Common", "Number"},
	{0x32C0, 0x32FE, "Common", "Symbol"},
	{0x3300, 0x33FF, "Common", "Symbol"},
	{0x3400, 0x4DB5, "Han", "Letter"},
	{0x4DC0, 0x4DFF, "Common", "Symbol"},
	{0x4E00, 0x9FBB, "Han", "Letter"},
	{0xA000, 0xA48C, "Yi", "Letter"},
	{0xA490, 0xA4C6, "Yi", "Symbol"},
	{0xA700, 0xA716, "Common", "Symbol"},
	{0xA717, 0xA71A, "Common", "Letter"},
	{0xA720, 0xA721, "Common", "Symbol"},
	{0xA800, 0xA801, "Syloti Nagri", "Letter"},
	{0xA802, 0xA802, "Syloti Nagri", "Mark"},
	{0xA803, 0xA805, "Syloti Nagri", "Letter"},
	{0xA806, 0xA806, "Syloti Nagri", "Mark"},
	{0xA807, 0xA80A, "Syloti Nagri", "Letter"},
	{0xA80B, 0xA80B, "Syloti Nagri", "Mark"},
	{0xA80C, 0xA822, "Syloti Nagri", "Letter"},
	{0xA823, 0xA827, "Syloti Nagri", "Mark"},
	{0xA828, 0xA82B, "Syloti Nagri", "Symbol"},
	{0xA840, 0xA873, "Phags Pa", "Letter"},
	{0xA874, 0xA877, "Phags Pa", "Punctuation"},
	{0xAC00, 0xD7A3, "Hangul", "Letter"},
	{0xF900, 0xFA2D, "Han", "Letter"},
	{0xFA30, 0xFA6A, "Han", "Letter"},
	{0xFA70, 0xFAD9, "Han", "Letter"},
	{0xFB00, 0xFB06, "Latin", "Letter"},
	{0xFB13, 0xFB17, "Armenian", "Letter"},
	{0xFB1D, 0xFB1D, "Hebrew", "Letter"},
	{0xFB1E, 0xFB1E, "Hebrew", "Mark"},
	{0xFB1F, 0xFB28, "Hebrew", "Letter"},
	{0xFB29, 0xFB29, "Hebrew", "Symbol"},
	{0xFB2A, 0xFB36, "Hebrew", "Letter"},
	{0xFB38, 0xFB3C, "Hebrew", "Letter"},
	{0xFB3E, 0xFB3E, "Hebrew", "Letter"},
	{0xFB40, 0xFB41, "Hebrew", "Letter"},
	{0xFB43, 0xFB44, "Hebrew", "Letter"},
	{0xFB46, 0xFB4F, "Hebrew", "Letter"},
	{0xFB50, 0xFBB1, "Arabic", "Letter"},
	{0xFBD3, 0xFD3D, "Arabic", "Letter"},
	{0xFD3E, 0xFD3F, "Common", "Punctuation"},
	{0xFD50, 0xFD8F, "Arabic", "Letter"},
	{0xFD92, 0xFDC7, "Arabic", "Letter"},
	{0xFDF0, 0xFDFB, "Arabic", "Letter"},
	{0xFDFC, 0xFDFC, "Arabic", "Currency Symbol"},
	{0xFDFD, 0xFDFD, "Common", "Symbol"},
	{0xFE00, 0xFE0F, "Inherited", "Mark"},
	{0xFE10, 0xFE19, "Common", "Punctuation"},
	{0xFE20, 0xFE23, "Inherited", "Mark"},
	{0xFE30, 0xFE52, "Common", "Punctuation"},
	{0xFE54, 0xFE61, "Common", "Punctuation"},
	{0xFE62, 0xFE62, "Common", "Symbol"},
	{0xFE63, 0xFE63, "Common", "Punctuation"},
	{0xFE64, 0xFE66, "Common", "Symbol"},
	{0xFE68, 0xFE68, "Common", "Punctuation"},
	{0xFE69, 0xFE69, "Common", "Currency Symbol"},
	{0xFE6A, 0xFE6B, "Common", "Punctuation"},
	{0xFE70, 0xFE74, "Arabic", "Letter"},
	{0xFE76, 0xFEFC, "Arabic", "Letter"},
	{0xFEFF, 0xFEFF, "Common", "Format"},
	{0xFF01, 0xFF03, "Common", "Punctuation"},
	{0xFF04, 0xFF04, "Common", "Currency Symbol"},
	{0xFF05, 0xFF0A, "Common", "Punctuation"},
	{0xFF0B, 0xFF0B, "Common", "Symbol"},
	{0xFF0C, 0xFF0F, "Common", "Punctuation"},
	{0xFF10, 0xFF19, "Common", "Number"},
	{0xFF1A, 0xFF1B, "Common", "Punctuation"},
	{0xFF1C, 0xFF1E, "Common", "Symbol"},
	{0xFF1F, 0xFF20, "Common", "Punctuation"},
	{0xFF21, 0xFF3A, "Latin", "Letter"},
	{0xFF3B, 0xFF3D, "Common", "Punctuation"},
	{0xFF3E, 0xFF3E, "Common", "Symbol"},
	{0xFF3F, 0xFF3F, "Common", "Punctuation"},
	{0xFF40, 0xFF40, "Common", "Symbol"},
	{0xFF41, 0xFF5A, "Latin", "Letter"},
	{0xFF5B, 0xFF5B, "Common", "Punctuation"},
	{0xFF5C, 0xFF5C, "Common", "Symbol"},
	{0xFF5D, 0xFF5D, "Common", "Punctuation"},
	{0xFF5E, 0xFF5E, "Common", "Symbol"},
	{0xFF5F, 0xFF65, "Common", "Punctuation"},
	{0xFF66, 0xFF6F, "Katakana", "Letter"},
	{0xFF70, 0xFF70, "Common", "Letter"},
	{0xFF71, 0xFF9D, "Katakana", "Letter"},
	{0xFF9E, 0xFF9F, "Common", "Letter"},
	{0xFFA0, 0xFFBE, "Hangul", "Letter"},
	{0xFFC2, 0xFFC7, "Hangul", "Letter"},
	{0xFFCA, 0xFFCF, "Hangul", "Letter"},
	{0xFFD2, 0xFFD7, "Hangul", "Letter"},
	{0xFFDA, 0xFFDC, "Hangul", "Letter"},
	{0xFFE0, 0xFFE1, "Common", "Currency Symbol"},
	{0xFFE2, 0xFFE4, "Common", "Symbol"},
	{0xFFE5, 0xFFE6, "Common", "Currency Symbol"},
	{0xFFE8, 0xFFEE, "Common", "Symbol"},
	{0xFFF9, 0xFFFB, "Common", "Format"},
	{0xFFFC, 0xFFFD, "Common", "Symbol"},
	{0x10000, 0x1000B, "Linear B", "Letter"},
	{0x1000D, 0x10026, "Linear B", "Letter"},
	{0x10028, 0x1003A, "Linear B", "Letter"},
	{0x1003C, 0x1003D, "Linear B", "Letter"},
	{0x1003F, 0x1004D, "Linear B", "Letter"},
	{0x10050, 0x1005D, "Linear B", "Letter"},
	{0x10080, 0x100FA, "Linear B", "Letter"},
	{0x10100, 0x10101, "Common", "Punctuation"},
	{0x10102, 0x10102, "Common", "Symbol"},
	{0x10107, 0x10133, "Common", "Number"},
	{0x10137, 0x1013F, "Common", "Symbol"},
	{0x10140, 0x10178, "Greek", "Number"},
	{0x10179, 0x10189, "Greek", "Symbol"},
	{0x1018A, 0x1018A, "Greek", "Number"},
	{0x10300, 0x1031E, "Old Italic", "Letter"},
	{0x10320, 0x10323, "Old Italic", "Number"},
	{0x10330, 0x10340, "Gothic", "Letter"},
	{0x10341, 0x10341, "Gothic", "Number"},
	{0x10342, 0x10349, "Gothic", "Letter"},
	{0x1034A, 0x1034A, "Gothic", "Number"},
	{0x10380, 0x1039D, "Ugaritic", "Letter"},
	{0x1039F, 0x1039F, "Ugaritic", "Punctuation"},
	{0x103A0, 0x103C3, "Old Persian", "Letter"},
	{0x103C8, 0x103CF, "Old Persian", "Letter"},
	{0x103D0, 0x103D0, "Old Persian", "Punctuation"},
	{0x103D1, 0x103D5, "Old Persian", "Number"},
	{0x10400, 0x1044F, "Deseret", "Letter"},
	{0x10450, 0x1047F, "Shavian", "Letter"},
	{0x10480, 0x1049D, "Osmanya", "Letter"},
	{0x104A0, 0x104A9, "Osmanya", "Number"},
	{0x10800, 0x10805, "Cypriot", "Letter"},
	{0x10808, 0x10808, "Cypriot", "Letter"},
	{0x1080A, 0x10835, "Cypriot", "Letter"},
	{0x10837, 0x10838, "Cypriot", "Letter"},
	{0x1083C, 0x1083C, "Cypriot", "Letter"},
	{0x1083F, 0x1083F, "Cypriot", "Letter"},
	{0x10900, 0x10915, "Phoenician", "Letter"},
	{0x10916, 0x10919, "Phoenician", "Number"},
	{0x1091F, 0x1091F, "Phoenician", "Punctuation"},
	{0x10A00, 0x10A00, "Kharoshthi", "Letter"},
	{0x10A01, 0x10A03, "Kharoshthi", "Mark"},
	{0x10A05, 0x10A06, "Kharoshthi", "Mark"},
	{0x10A0C, 0x10A0F, "Kharoshthi", "Mark"},
	{0x10A10, 0x10A13, "Kharoshthi", "Letter"},
	{0x10A15, 0x10A17, "Kharoshthi", "Letter"},
	{0x10A19, 0x10A33, "Kharoshthi", "Letter"},
	{0x10A38, 0x10A3A, "Kharoshthi", "Mark"},
	{0x10A3F, 0x10A3F, "Kharoshthi", "Mark"},
	{0x10A40, 0x10A47, "Kharoshthi", "Number"},
	{0x10A50, 0x10A58, "Kharoshthi", "Punctuation"},
	{0x12000, 0x1236E, "Cuneiform", "Letter"},
	{0x12400, 0x12462, "Cuneiform", "Number"},
	{0x12470, 0x12473, "Cuneiform", "Punctuation"},
	{0x1D000, 0x1D0F5, "Common", "Symbol"},
	{0x1D100, 0x1D126, "Common", "Symbol"},
	{0x1D12A, 0x1D164, "Common", "Symbol"},
	{0x1D165, 0x1D166, "Common", "Mark"},
	{0x1D167, 0x1D169, "Inherited", "Mark"},
	{0x1D16A, 0x1D16C, "Common", "Symbol"},
	{0x1D16D, 0x1D172, "Common", "Mark"},
	{0x1D173, 0x1D17A, "Common", "Format"},
	{0x1D17B, 0x1D182, "Inherited", "Mark"},
	{0x1D183, 0x1D184, "Common", "Symbol"},
	{0x1D185, 0x1D18B, "Inherited", "Mark"},
	{0x1D18C, 0x1D1A9, "Common", "Symbol"},
	{0x1D1AA, 0x1D1AD, "Inherited", "Mark"},
	{0x1D1AE, 0x1D1DD, "Common", "Symbol"},
	{0x1D200, 0x1D241, "Greek", "Symbol"},
	{0x1D242, 0x1D244, "Greek", "Mark"},
	{0x1D245, 0x1D245, "Greek", "Symbol"},
	{0x1D300, 0x1D356, "Common", "Symbol"},
	{0x1D360, 0x1D371, "Common", "Number"},
	{0x1D400, 0x1D454, "Common", "Letter"},
	{0x1D456, 0x1D49C, "Common", "Letter"},
	{0x1D49E, 0x1D49F, "Common", "Letter"},
	{0x1D4A2, 0x1D4A2, "Common", "Letter"},
	{0x1D4A5, 0x1D4A6, "Common", "Letter"},
	{0x1D4A9, 0x1D4AC, "Common", "Letter"},
	{0x1D4AE, 0x1D4B9, "Common", "Letter"},
	{0x1D4BB, 0x1D4BB, "Common", "Letter"},
	{0x1D4BD, 0x1D4C3, "Common", "Letter"},
	{0x1D4C5, 0x1D505, "Common", "Letter"},
	{0x1D507, 0x1D50A, "Common", "Letter"},
	{0x1D50D, 0x1D514, "Common", "Letter"},
	{0x1D516, 0x1D51C, "Common", "Letter"},
	{0x1D51E, 0x1D539, "Common", "Letter"},
	{0x1D53B, 0x1D53E, "Common", "Letter"},
	{0x1D540, 0x1D544, "Common", "Letter"},
	{0x1D546, 0x1D546, "Common", "Letter"},
	{0x1D54A, 0x1D550, "Common", "Letter"},
	{0x1D552, 0x1D6A5, "Common", "Letter"},
	{0x1D6A8, 0x1D6C0, "Common", "Letter"},
	{0x1D6C1, 0x1D6C1, "Common", "Symbol"},
	{0x1D6C2, 0x1D6DA, "Common", "Letter"},
	{0x1D6DB, 0x1D6DB, "Common", "Symbol"},
	{0x1D6DC, 0x1D6FA, "Common", "Letter"},
	{0x1D6FB, 0x1D6FB, "Common", "Symbol"},
	{0x1D6FC, 0x1D714, "Common", "Letter"},
	{0x1D715, 0x1D715, "Common", "Symbol"},
	{0x1D716, 0x1D734, "Common", "Letter"},
	{0x1D735, 0x1D735, "Common", "Symbol"},
	{0x1D736, 0x1D74E, "Common", "Letter"},
	{0x1D74F, 0x1D74F, "Common", "Symbol"},
	{0x1D750, 0x1D76E, "Common", "Letter"},
	{0x1D76F, 0x1D76F, "Common", "Symbol"},
	{0x1D770, 0x1D788, "Common", "Letter"},
	{0x1D789, 0x1D789, "Common", "Symbol"},
	{0x1D78A, 0x1D7A8, "Common", "Letter"},
	{0x1D7A9, 0x1D7A9, "Common", "Symbol"},
	{0x1D7AA, 0x1D7C2, "Common", "Letter"},
	{0x1D7C3, 0x1D7C3, "Common", "Symbol"},
	{0x1D7C4, 0x1D7CB, "Common", "Letter"},
	{0x1D7CE, 0x1D7FF, "Common", "Number"},
	{0x20000, 0x2A6D6, "Han", "Letter"},
	{0x2F800, 0x2FA1D, "Han", "Letter"},
	{0xE0001, 0xE0001, "Common", "Format"},
	{0xE0020, 0xE007F, "Common", "Format"},
	{0xE0100, 0xE01EF, "Inherited", "Mark"},
